@@ -595,7 +595,10 @@ def tox_addoption(parser):
     )
 
     def _set_envdir_from_devenv(testenv_config, value):
-        if testenv_config.config.option.devenv is not None:
+        if (
+            testenv_config.config.option.devenv is not None
+            and testenv_config.envname != testenv_config.config.provision_tox_env
+        ):
             return py.path.local(testenv_config.config.option.devenv)
         else:
             return value
@@ -767,6 +770,7 @@ def tox_addoption(parser):
             "CURL_CA_BUNDLE",
             "LANG",
             "LANGUAGE",
+            "LC_ALL",
             "LD_LIBRARY_PATH",
             "PATH",
             "PIP_INDEX_URL",
@@ -1557,7 +1561,7 @@ def _split_env(env):
         return []
     if not isinstance(env, list):
         env = [e.split("#", 1)[0].strip() for e in env.split("\n")]
-        env = ",".join([e for e in env if e])
+        env = ",".join(e for e in env if e)
         env = [env]
     return mapcat(_expand_envstr, env)
 
@@ -1789,7 +1793,7 @@ class SectionReader:
             if sys.platform.startswith("win"):
                 posargs_string = list2cmdline([x for x in posargs if x])
             else:
-                posargs_string = " ".join([shlex_quote(x) for x in posargs if x])
+                posargs_string = " ".join(shlex_quote(x) for x in posargs if x)
             return posargs_string
         else:
             return default or ""
